Struct toml_edit::InlineOccupiedEntry [−][src]
pub struct InlineOccupiedEntry<'a> { /* fields omitted */ }Expand description
A view into a single occupied location in a IndexMap.
Implementations
Gets a reference to the entry key
Examples
use toml_edit::Table;
let mut map = Table::new();
assert_eq!("foo", map.entry("foo").key());Converts the OccupiedEntry into a mutable reference to the value in the entry with a lifetime bound to the map itself
Sets the value of the entry, and returns the entry’s old value